@@ -192,15 +192,23 @@ func TestUnescapeIdent(t *testing.T) {
 	}
 	f("", "")
 	f("a", "a")
-	f("\\", "")
+	f("\\", `\`)
 	f(`\\`, `\`)
 	f(`\foo\-bar`, `foo-bar`)
 	f(`a\\\\b\"c\d`, `a\\b"cd`)
 	f(`foo.bar:baz_123`, `foo.bar:baz_123`)
 	f(`foo\ bar`, `foo bar`)
 	f(`\x21`, `!`)
-	f(`\xeDfoo\x2Fbar\-\xqw\x`, "\xedfoo\x2fbar-xqwx")
+	f(`\X21`, `!`)
+	f(`\x7Dfoo\x2Fbar\-\xqw\x`, "}foo/bar-\\xqw\\x")
 	f(`\п\р\и\в\е\т123`, "привет123")
+	f(`123`, `123`)
+	f(`\123`, `123`)
+	f(`привет\-\foo`, "привет-foo")
+	f(`\u0965`, "\u0965")
+	f(`\U0965`, "\u0965")
+	f(`\u202c`, "\u202c")
+	f(`\U202ca`, "\u202ca")
 }
 
 func TestAppendEscapedIdent(t *testing.T) {
@@ -214,9 +222,13 @@ func TestAppendEscapedIdent(t *testing.T) {
 	f(`a`, `a`)
 	f(`a.b:c_23`, `a.b:c_23`)
 	f(`a b-cd+dd\`, `a\ b\-cd\+dd\\`)
-	f("a\x1E\x20\xee", `a\x1e\ \xee`)
-	f("\x2e\x2e", `\x2e.`)
-	f("привет123", `\п\р\и\в\е\т123`)
+	f("a\x1E\x20\x7e", `a\x1e\ \~`)
+	f("\x2e\x2e", `\..`)
+	f("123", `\123`)
+	f("+43.6", `\+43.6`)
+	f("привет123(a-b)", `привет123\(a\-b\)`)
+	f("\u0965", `\॥`)
+	f("\u202c", `\u202c`)
 }
 
 func TestScanIdent(t *testing.T) {
@@ -232,8 +244,23 @@ func TestScanIdent(t *testing.T) {
 	f("a+b", "a")
 	f("foo()", "foo")
 	f(`a\-b+c`, `a\-b`)
-	f(`a\ b\\\ c\`, `a\ b\\\ c\`)
+	f(`a\ b\\\ c\`, `a\ b\\\ c`)
 	f(`\п\р\и\в\е\т123`, `\п\р\и\в\е\т123`)
+	f(`привет123!foo`, `привет123`)
+	f(`\1fooЫ+bar`, `\1fooЫ`)
+	f(`\u7834*аа`, `\u7834`)
+	f(`\U7834*аа`, `\U7834`)
+	f(`\x7834*аа`, `\x7834`)
+	f(`\X7834*аа`, `\X7834`)
+	f(`a\x+b`, `a`)
+	f(`a\x1+b`, `a`)
+	f(`a\x12+b`, `a\x12`)
+	f(`a\u+b`, `a`)
+	f(`a\u1+b`, `a`)
+	f(`a\u12+b`, `a`)
+	f(`a\u123+b`, `a`)
+	f(`a\u1234+b`, `a\u1234`)
+	f("a\\\u202c", `a`)
 }
 
 func TestLexerNextPrev(t *testing.T) {
@@ -442,9 +469,6 @@ func TestLexerError(t *testing.T) {
 	testLexerError(t, `'`)
 	testLexerError(t, "`")
 
-	// Unrecognized char
-	testLexerError(t, "тест")
-
 	// Invalid numbers
 	testLexerError(t, `.`)
 	testLexerError(t, `12e`)
@@ -513,6 +537,13 @@ func TestPositiveDurationSuccess(t *testing.T) {
 	f("1.23", 45, 1230)
 	f("0.56", 12, 560)
 	f(".523e2", 21, 52300)
+
+	// Duration suffixes in mixed case.
+	f("1Ms", 45, 1)
+	f("1mS", 45, 1)
+	f("1H", 45, 1*60*60*1000)
+	f("1D", 45, 1*24*60*60*1000)
+	f("1Y", 45, 1*365*24*60*60*1000)
 }
 
 func TestPositiveDurationError(t *testing.T) {
@@ -532,9 +563,16 @@ func TestPositiveDurationError(t *testing.T) {
 	f("1.23mm")
 	f("123q")
 	f("-123s")
+	f("1.23.4434s")
+	f("1mi")
+	f("1mb")
 
 	// Too big duration
 	f("10000000000y")
+
+	// Uppercase M isn't a duration, but a 1e6 multiplier.
+	// See https://github.com/VictoriaMetrics/VictoriaMetrics/issues/3664
+	f("1M")
 }
 
 func TestDurationSuccess(t *testing.T) {
@@ -588,6 +626,15 @@ func TestDurationSuccess(t *testing.T) {
 	f("1.23", 45, 1230)
 	f("-0.56", 12, -560)
 	f("-.523e2", 21, -52300)
+
+	// Duration suffix in mixed case.
+	f("-1Ms", 10, -1)
+	f("-2.5mS", 10, -2)
+	f("-1mS", 10, -1)
+	f("-1H", 10, -1*60*60*1000)
+	f("-3.H", 10, -3*60*60*1000)
+	f("1D", 10, 1*24*60*60*1000)
+	f("-.1Y", 10, -0.1*365*24*60*60*1000)
 }
 
 func TestDurationError(t *testing.T) {
@@ -607,4 +654,10 @@ func TestDurationError(t *testing.T) {
 	f("1.23mm")
 	f("123q")
 	f("-123q")
+	f("-5.3mb")
+	f("-5.3mi")
+
+	// M isn't a duration, but a 1e6 multiplier.
+	// See https://github.com/VictoriaMetrics/VictoriaMetrics/issues/3664
+	f("-5.3M")
 }
