@@ -106,7 +106,9 @@ func TestParseSuccess(t *testing.T) {
 	// identifiers with with escape chars
 	same(`foo\ bar`)
 	same(`foo\-bar\{{baz\+bar="aa"}`)
-	another(`\x2E\x2ef\oo{b\xEF\ar="aa"}`, `\x2e.foo{b\xefar="aa"}`)
+	another(`\x2E\x2ef\oo{b\xEF\ar="aa"}`, `\..foo{bïar="aa"}`)
+	same(`温度{房间="水电费"}[5m] offset 10m`)
+	another(`\温\度{\房\间="水电费"}[5m] offset 10m`, `温度{房间="水电费"}[5m] offset 10m`)
 	same(`sum(fo\|o) by (b\|a, x)`)
 	another(`sum(x) by (b\x7Ca)`, `sum(x) by (b\|a)`)
 	// Duplicate filters
@@ -144,6 +146,14 @@ func TestParseSuccess(t *testing.T) {
 	same(`foo - 123.`)
 	same(`12.e+4`)
 	same(`12Ki`)
+	same(`12Kib`)
+	same(`12Mi`)
+	same(`12Mb`)
+	same(`12MB`)
+	same(`(rate(foo)[5m] * 8) > 45Mi`)
+	same(`(rate(foo)[5m] * 8) > 45mi`)
+	same(`(rate(foo)[5m] * 8) > 45mI`)
+	same(`(rate(foo)[5m] * 8) > 45Mib`)
 	same(`1.23Gb`)
 	same(`foo - 23M`)
 	another(`-1.23Gb`, `-1.23e+09`)
@@ -182,6 +192,7 @@ func TestParseSuccess(t *testing.T) {
 	same(`1h`)
 	another(`-1h`, `0 - 1h`)
 	same(`0.34h4m5s`)
+	same(`0.34H4m5S`)
 	another(`-0.34h4m5s`, `0 - 0.34h4m5s`)
 	same(`sum_over_tme(m[1h]) / 1h`)
 	same(`sum_over_time(m[3600]) / 3600`)
@@ -497,6 +508,7 @@ func TestParseError(t *testing.T) {
 	f("  \t\b\r\n  ")
 
 	// invalid metricExpr
+	f(`{}[5M:]`)
 	f(`foo[-55]`)
 	f(`m[-5m]`)
 	f(`{`)
